<?php

class FagePictureWidget extends WP_Widget {
    const WHICH_RANDOM = 1;
    const WHICH_LATEST = 2;
    
    
    private $images = null;
    private $numImages = 0;
        
    
    /** constructor */
    public function __construct() {
        if ('' == session_id()) {
            session_start();
        }
        
        parent::__construct(false, 'Flash Gallery Image');
        
        if (!empty($_GET['fagePid']) && !empty($_GET['fageGid'])) {
            $_SESSION['fagePid'] = $_GET['fagePid'];
            $_SESSION['fageGid'] = $_GET['fageGid'];
        }
    }

    /** @see WP_Widget::widget */
    function widget($args, $instance) {

        $message =
            $args['before_widget'] .
            $args['before_title'] .
            $instance['title'] .
            $args['after_title'];
        
        if ($instance['antiCache'] == 1) {
            if (self::WHICH_RANDOM == $instance['which']) {
                $thumbUrl = FAGE_ANTICAHE_RANDOM_THUMB;
            } else {
                $thumbUrl = FAGE_ANTICAHE_LATEST_THUMB;
            }
            
            // Image and gallery ids will besaved in the session when the thumbnail
            // is generated. Problems start when multiple tabs/windows of the page
            // are opened by the same user.
            $url = $instance['galUrl'];
        } else {
            if (self::WHICH_RANDOM == $instance['which']) {
                $imageInfo = FageTools::getRandomImageInfo();
            } else {
                $imageInfo = FageTools::getLatestImageInfo();
            }

            $thumbUrl = $imageInfo['thumbUrl'];
            $url =
                $instance['galUrl'] .
                '?fagePid='. urlencode($imageInfo['pid']) .
                '&fageGid='. urlencode($imageInfo['gid']);
        }
            

        
        
        $message .= '
            <p style="text-align: center;">
              <a href="'. $url .'">
                <img src="'. $thumbUrl .
                '" alt="Random Picture" style="border-width: 0px;"/>
              </a>
            </p>';
        
        $message .= '
            </p>'. $instance['additionalText'];
        
        $message .= $args['after_widget'];
        
        echo $message;
    }

    /** @see WP_Widget::update */
    function update($new_instance, $old_instance) {
        return $new_instance;
    }

    /** @see WP_Widget::form */
    function form($instance) {
        $title = esc_attr($instance['title']);
        $titleFieldId = $this->get_field_id('title');
        $titleFieldName = $this->get_field_name('title');
        
        $which = esc_attr($instance['which']);
        $whichFieldId = $this->get_field_id('which');
        $whichFieldName = $this->get_field_name('which');
        
        $galUrl = esc_attr($instance['galUrl']);
        $galUrlFieldId = $this->get_field_id('galUrl');
        $galUrlFieldName = $this->get_field_name('galUrl');
        
        $additionalText = esc_attr($instance['additionalText']);
        $additionalTextFieldId = $this->get_field_id('additionalText');
        $additionalTextFieldName = $this->get_field_name('additionalText');
        
        
        $antiCache = esc_attr($instance['antiCache']);
        $antiCacheFieldId = $this->get_field_id('antiCache');
        $antiCacheFieldName = $this->get_field_name('antiCache');
        $antiCacheChecked = $antiCache == 1 ? ' checked="checked"' : '';
        
        echo '
            <p>
              <label for="'. $titleFieldId .'">'. __('Title:') .'</label>
              <input class="widefat" id="'. $titleFieldId .'" name="'.
                $titleFieldName .'" type="text" value="'. $title .'"/>
              
            </p>
            <p>
              <label for="'. $whichFieldId .'">'. __('Which:') .'</label>
              <select class="fat"  id="'. $whichFieldId .'" name="'.
                $whichFieldName .'">
                  <option value="'. self::WHICH_RANDOM .'"'.
                    ($which == self::WHICH_RANDOM ? ' selected="selected"' : '') .
                    '>'. __('Zuf&auml;llig') .'</option>
                  <option value="'. self::WHICH_LATEST .'"'.
                    ($which == self::WHICH_LATEST ? ' selected="selected"' : '') .
                    '>'. __('Aktuelles') .'</option>
              </select>
            </p>
            <p>
              <label for="'. $galUrlFieldId .'">'. __('URL for all Galleries:') .'</label>
              <input class="widefat" id="'. $galUrlFieldId .'" name="'.
                $galUrlFieldName .'" type="text" value="'. $galUrl .'"/>
            </p>
            <p>
              <label for="'. $additionalTextFieldId .'">'. __('Additional Text:') .
                '</label>
                <textarea class="widefat" id="'. $additionalTextFieldId .
                '" name="'. $additionalTextFieldName .'" style="font-size: 0.8em">'.
                $additionalText .'</textarea>
            </p>
            <p>
              <label for="'. $antiCacheFieldId .'">'. __('Work around cache:') .
              '</label> <input class="checkbox" id="'. $antiCacheFieldId .
              '" name="'. $antiCacheFieldName .'" type="checkbox" value="1"'.
              $antiCacheChecked .' />
            </p>';
    }

} // class FageRandomPictureWidget
